@@ -1,12 +1,27 @@
 import socket
-import sqlalchemy
-import databases
 from importlib import import_module
 
+import databases
+import sqlalchemy
+
+second = 1
+minute = 60 * second
+hour = 60 * minute
+day = 24 * hour
+year = 365 * day
+
+
+class Auth:
+    def __init__(self, secure=True, expire=hour, refresh_expire=year):
+        self.secure = secure
+        self.expire = expire
+        self.refresh_expire = refresh_expire
+
 
 class BaseConfig:
     name = "App Name"
     version = "0.0.1"
+    api_root = "/api/v1"
     hostname = socket.gethostname()
     port = 5000
     debug = False
@@ -15,16 +30,18 @@ class BaseConfig:
     database = None
     engine = None
     secret = "SECRET"
-    cookie_secure = True
-    user = 'freenit.models.user'
+    user = "freenit.models.ormar"
     meta = None
+    auth = Auth()
 
     def __init__(self):
         self.database = databases.Database(self.dburl)
         self.engine = sqlalchemy.create_engine(self.dburl)
+
         class Meta:
             database = self.database
             metadata = self.metadata
+
         self.meta = Meta
 
     def __repr__(self):
@@ -38,21 +55,21 @@ class BaseConfig:
     @classmethod
     def envname(cls):
         classname = cls.__name__.lower()
-        if classname.endswith('config'):
-            return classname[:-len('config')]
+        if classname.endswith("config"):
+            return classname[: -len("config")]
         return classname
 
 
 class DevConfig(BaseConfig):
     debug = True
-    cookie_secure = False
     dburl = "sqlite:///db.sqlite"
+    auth = Auth(False)
 
 
 class TestConfig(BaseConfig):
     debug = True
-    cookie_secure = False
     dburl = "sqlite:///test.sqlite"
+    auth = Auth(False)
 
 
 class ProdConfig(BaseConfig):
